@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: meta.c,v 1.1.2.38 2003/07/29 22:59:00 guus Exp $
+    $Id: meta.c,v 1.1.2.41 2003/08/12 14:48:12 guus Exp $
 */
 
 #include "system.h"
@@ -27,14 +27,15 @@
 #include "avl_tree.h"
 #include "connection.h"
 #include "logger.h"
+#include "meta.h"
 #include "net.h"
 #include "protocol.h"
 #include "system.h"
 #include "utils.h"
 
-bool send_meta(connection_t *c, char *buffer, int length)
+bool send_meta(connection_t *c, const char *buffer, int length)
 {
-	char *bufp;
+	const char *bufp;
 	int outlen;
 	char outbuf[MAXBUFSIZE];
 	int result;
@@ -54,10 +55,14 @@ bool send_meta(connection_t *c, char *buffer, int length)
 	while(length) {
 		result = send(c->socket, bufp, length, 0);
 		if(result <= 0) {
-			if(errno == EINTR)
+			if(!errno || errno == EPIPE) {
+				ifdebug(CONNECTIONS) logger(LOG_NOTICE, _("Connection closed by %s (%s)"),
+						   c->name, c->hostname);
+			} else if(errno == EINTR)
 				continue;
-			logger(LOG_ERR, _("Sending meta data to %s (%s) failed: %s"), c->name,
-				   c->hostname, strerror(errno));
+			else
+				logger(LOG_ERR, _("Sending meta data to %s (%s) failed: %s"), c->name,
+					   c->hostname, strerror(errno));
 			return false;
 		}
 		bufp += result;
@@ -67,7 +72,7 @@ bool send_meta(connection_t *c, char *buffer, int length)
 	return true;
 }
 
-void broadcast_meta(connection_t *from, char *buffer, int length)
+void broadcast_meta(connection_t *from, const char *buffer, int length)
 {
 	avl_node_t *node;
 	connection_t *c;
@@ -117,7 +122,7 @@ bool receive_meta(connection_t *c)
 	lenin = recv(c->socket, c->buffer + c->buflen, MAXBUFSIZE - c->buflen, 0);
 
 	if(lenin <= 0) {
-		if(lenin == 0) {
+		if(!lenin || !errno) {
 			ifdebug(CONNECTIONS) logger(LOG_NOTICE, _("Connection closed by %s (%s)"),
 					   c->name, c->hostname);
 		} else if(errno == EINTR)
