@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: process.c,v 1.1.2.63 2003/08/03 21:45:13 guus Exp $
+    $Id: process.c,v 1.1.2.71 2003/08/10 13:35:05 guus Exp $
 */
 
 #include "system.h"
@@ -84,6 +84,8 @@ static SERVICE_STATUS_HANDLE statushandle = 0;
 bool install_service(void) {
 	char command[4096] = "";
 	char **argp;
+	bool space;
+	SERVICE_DESCRIPTION description = {"Virtual Private Network daemon"};
 
 	manager = OpenSCManager(NULL, NULL, SC_MANAGER_ALL_ACCESS);
 	if(!manager) {
@@ -98,8 +100,16 @@ bool install_service(void) {
 
 	strncat(command, program_name, sizeof(command));
 	for(argp = g_argv + 1; *argp; argp++) {
+		space = strchr(*argp, ' ');
 		strncat(command, " ", sizeof(command));
+		
+		if(space)
+			strncat(command, "\"", sizeof(command));
+		
 		strncat(command, *argp, sizeof(command));
+
+		if(space)
+			strncat(command, "\"", sizeof(command));
 	}
 
 	service = CreateService(manager, identname, identname,
@@ -111,6 +121,8 @@ bool install_service(void) {
 		return false;
 	}
 
+	ChangeServiceConfig2(service, SERVICE_CONFIG_DESCRIPTION, &description);
+
 	logger(LOG_INFO, _("%s service installed"), identname);
 
 	if(!StartService(service, 0, NULL))
@@ -166,6 +178,7 @@ DWORD WINAPI controlhandler(DWORD request, DWORD type, LPVOID boe, LPVOID bah) {
 	}
 
 	if(!running) {
+		status.dwWaitHint = 30000; 
 		status.dwCurrentState = SERVICE_STOP_PENDING; 
 		SetServiceStatus(statushandle, &status);
 	}
@@ -184,7 +197,6 @@ VOID WINAPI run_service(DWORD argc, LPTSTR* argv)
 	status.dwWin32ExitCode = 0; 
 	status.dwServiceSpecificExitCode = 0; 
 	status.dwCheckPoint = 0; 
-	status.dwWaitHint = 0; 
 
 	statushandle = RegisterServiceCtrlHandlerEx(identname, controlhandler, NULL); 
 
@@ -192,14 +204,17 @@ VOID WINAPI run_service(DWORD argc, LPTSTR* argv)
 		logger(LOG_ERR, _("System call `%s' failed: %s"), "RegisterServiceCtrlHandlerEx", winerror(GetLastError()));
 		err = 1;
 	} else {
+		status.dwWaitHint = 30000; 
 		status.dwCurrentState = SERVICE_START_PENDING; 
 		SetServiceStatus(statushandle, &status);
 
+		status.dwWaitHint = 0; 
 		status.dwCurrentState = SERVICE_RUNNING;
 		SetServiceStatus(statushandle, &status);
 
 		err = main2(argc, argv);
 
+		status.dwWaitHint = 0;
 		status.dwCurrentState = SERVICE_STOPPED; 
 		//status.dwWin32ExitCode = err; 
 		SetServiceStatus(statushandle, &status);
@@ -344,53 +359,16 @@ bool detach(void)
 	return true;
 }
 
-#ifdef HAVE_FORK
-/*
-  Execute the program name, with sane environment.
-*/
-static void _execute_script(const char *scriptname, char **envp)
-	__attribute__ ((__noreturn__));
-static void _execute_script(const char *scriptname, char **envp)
-{
-	int save_errno;
-
-	cp();
-
-	while(*envp)
-		putenv(*envp++);
-
-	chdir("/");
-
-	closelogger();
-
-	/* Close all file descriptors */
-	fcloseall();
-
-	execl(scriptname, scriptname, NULL);
-	/* No return on success */
-
-	save_errno = errno;
-
-	openlogger(identname, use_logfile?LOGMODE_FILE:(do_detach?LOGMODE_SYSLOG:LOGMODE_STDERR));
-	logger(LOG_ERR, _("Could not execute `%s': %s"), scriptname,
-		   strerror(save_errno));
-	exit(save_errno);
-}
-#endif
-
-/*
-  Fork and execute the program pointed to by name.
-*/
 bool execute_script(const char *name, char **envp)
 {
-#ifdef HAVE_FORK
-	pid_t pid;
+#ifdef HAVE_SYSTEM
 	int status;
 	struct stat s;
 	char *scriptname;
 
 	cp();
 
+#ifndef HAVE_MINGW
 	asprintf(&scriptname, "%s/%s", confbase, name);
 
 	/* First check if there is a script */
@@ -398,52 +376,48 @@ bool execute_script(const char *name, char **envp)
 	if(stat(scriptname, &s))
 		return true;
 
-	pid = fork();
+	ifdebug(STATUS) logger(LOG_INFO, _("Executing script %s"), name);
 
-	if(pid < 0) {
-		logger(LOG_ERR, _("System call `%s' failed: %s"), "fork",
-			   strerror(errno));
-		return false;
-	}
+	free(scriptname);
+#endif
 
-	if(pid) {
-		ifdebug(STATUS) logger(LOG_INFO, _("Executing script %s"), name);
+#ifdef HAVE_PUTENV
+	/* Set environment */
+	
+	while(*envp)
+		putenv(*envp++);
+#endif
 
-		free(scriptname);
+	asprintf(&scriptname, "\"%s/%s\"", confbase, name);
+	status = system(scriptname);
 
-		if(waitpid(pid, &status, 0) == pid) {
-			if(WIFEXITED(status)) {	/* Child exited by itself */
-				if(WEXITSTATUS(status)) {
-					logger(LOG_ERR, _("Process %d (%s) exited with non-zero status %d"),
-						   pid, name, WEXITSTATUS(status));
-					return false;
-				} else
-					return true;
-			} else if(WIFSIGNALED(status)) {	/* Child was killed by a signal */
-				logger(LOG_ERR, _("Process %d (%s) was killed by signal %d (%s)"), pid,
-					   name, WTERMSIG(status), strsignal(WTERMSIG(status)));
-				return false;
-			} else {			/* Something strange happened */
-				logger(LOG_ERR, _("Process %d (%s) terminated abnormally"), pid,
-					   name);
+	free(scriptname);
+
+	/* Unset environment? */
+
+#ifdef WEXITSTATUS
+	if(status != -1) {
+		if(WIFEXITED(status)) {	/* Child exited by itself */
+			if(WEXITSTATUS(status)) {
+				logger(LOG_ERR, _("Script %s exited with non-zero status %d"),
+					   name, WEXITSTATUS(status));
 				return false;
 			}
-		} else if (errno != EINTR) {
-			logger(LOG_ERR, _("System call `%s' failed: %s"), "waitpid",
-				   strerror(errno));
+		} else if(WIFSIGNALED(status)) {	/* Child was killed by a signal */
+			logger(LOG_ERR, _("Script %s was killed by signal %d (%s)"),
+				   name, WTERMSIG(status), strsignal(WTERMSIG(status)));
+			return false;
+		} else {			/* Something strange happened */
+			logger(LOG_ERR, _("Script %s terminated abnormally"), name);
 			return false;
 		}
-
-		/* Why do we get EINTR? */
-		return true;
+	} else {
+		logger(LOG_ERR, _("System call `%s' failed: %s"), "system", strerror(errno));
+		return false;
 	}
-
-	/* Child here */
-
-	_execute_script(scriptname, envp);
-#else
-	return true;
 #endif
+#endif
+	return true;
 }
 
 
